@@ -18,7 +18,7 @@ from casperlabs_client import (
     DEFAULT_INTERNAL_PORT,
     bundled_contract,
 )
-from casperlabs_client.utils import hexify
+from casperlabs_client.utils import hexify, jsonify
 from casperlabs_client.abi import ABI
 from casperlabs_client.crypto import (
     read_pem_key,
@@ -158,16 +158,11 @@ def _deploy_kwargs(args, private_key_accepted=True):
         args.payment_args = ABI.args_to_json(
             ABI.args([ABI.big_int("amount", int(args.payment_amount))])
         )
-        # Unless one of payment* options supplied use bundled standard-payment
-        if not any(
-            (args.payment, args.payment_name, args.payment_hash, args.payment_uref)
-        ):
-            args.payment = bundled_contract("standard_payment.wasm")
 
     d = dict(
         from_addr=from_addr,
         gas_price=args.gas_price,
-        payment=args.payment or args.session,
+        payment=args.payment,
         session=args.session,
         public_key=args.public_key or None,
         session_args=args.session_args
@@ -383,12 +378,16 @@ def stream_events_command(casperlabs_client, args):
         account_public_keys=args.account_public_key,
         deploy_hashes=args.deploy_hash,
         min_event_id=args.min_event_id,
+        max_event_id=args.max_event_id,
         **subscribed_events,
     )
     for event in stream:
-        now = datetime.datetime.now()
-        print(f"------------- {now.strftime('%Y-%m-%d %H:%M:%S')} -------------")
-        print(hexify(event))
+        if args.format == "binary":
+            print(base64.b64encode(event.SerializeToString()).decode())
+        elif args.format == "json":
+            print(jsonify(event))
+        else:
+            print(hexify(event))
 
 
 def check_directory(path):
@@ -435,7 +434,7 @@ def deploy_options(private_key_accepted=True):
         [('--dependencies',), dict(required=False, nargs="+", default=None, help="List of deploy hashes (base16 encoded) which must be executed before this deploy.")],
         [('--payment-amount',), dict(required=False, type=int, default=None, help="Standard payment amount. Use this with the default payment, or override with --payment-args if custom payment code is used. By default --payment-amount is set to 10000000")],
         [('--gas-price',), dict(required=False, type=int, default=10, help='The price of gas for this transaction in units dust/gas. Must be positive integer.')],
-        [('-p', '--payment'), dict(required=False, type=str, default=None, help='Path to the file with payment code, by default fallbacks to the --session code')],
+        [('-p', '--payment'), dict(required=False, type=str, default=None, help='Path to the file with payment code')],
         [('--payment-hash',), dict(required=False, type=str, default=None, help='Hash of the stored contract to be called in the payment; base16 encoded')],
         [('--payment-name',), dict(required=False, type=str, default=None, help='Name of the stored contract (associated with the executing account) to be called in the payment')],
         [('--payment-uref',), dict(required=False, type=str, default=None, help='URef of the stored contract to be called in the payment; base16 encoded')],
@@ -632,7 +631,9 @@ def cli(*arguments) -> int:
         [('--deploy-orphaned',), dict(action='store_true', help='Deploy orphaned')],
         [('-k', '--account-public-key'), dict(action='append', help='Filter by (possibly multiple) account public key(s)')],
         [('-d', '--deploy-hash'), dict(action='append', help='Filter by (possibly multiple) deploy hash(es)')],
+        [('-f', '--format'), dict(required=False, default='text', choices=('json', 'binary', 'text') ,help='Choose output format. Defaults to text representation.')],
         [('--min-event-id',), dict(required=False, default=0, type=int, help="Supports replaying events from a given ID. If the value is 0, it it will subscribe to future events; if it's non-zero, it will replay all past events from that ID, without subscribing to new. To catch up with events from the beginning, start from 1.")],
+        [('--max-event-id',), dict(required=False, default=0, type=int, help="Supports replaying events to a given ID.")],
     ])
     # fmt:on
     return parser.run([str(a) for a in arguments])
